==> mktcenter-service-threetree-1.0-20250918.062252-17-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationCertPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktActivityCertificationCertPO {
    private Long mktActivityCertificationCertId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktActivityCertificationId;

    private Long certificationTypeId;

    private String membersCode;

    private String memberPhone;

    private String certImg;

    private String certLevel;

    private String certNo;

    private Integer certState;

    private Date issueTime;

    private Date expireTime;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktActivityCertificationCertId() {
        return mktActivityCertificationCertId;
    }

    public void setMktActivityCertificationCertId(Long mktActivityCertificationCertId) {
        this.mktActivityCertificationCertId = mktActivityCertificationCertId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public Long getCertificationTypeId() {
        return certificationTypeId;
    }

    public void setCertificationTypeId(Long certificationTypeId) {
        this.certificationTypeId = certificationTypeId;
    }

    public String getMembersCode() {
        return membersCode;
    }

    public void setMembersCode(String membersCode) {
        this.membersCode = membersCode == null ? null : membersCode.trim();
    }

    public String getMemberPhone() {
        return memberPhone;
    }

    public void setMemberPhone(String memberPhone) {
        this.memberPhone = memberPhone == null ? null : memberPhone.trim();
    }

    public String getCertImg() {
        return certImg;
    }

    public void setCertImg(String certImg) {
        this.certImg = certImg == null ? null : certImg.trim();
    }

    public String getCertLevel() {
        return certLevel;
    }

    public void setCertLevel(String certLevel) {
        this.certLevel = certLevel == null ? null : certLevel.trim();
    }

    public String getCertNo() {
        return certNo;
    }

    public void setCertNo(String certNo) {
        this.certNo = certNo == null ? null : certNo.trim();
    }

    public Integer getCertState() {
        return certState;
    }

    public void setCertState(Integer certState) {
        this.certState = certState;
    }

    public Date getIssueTime() {
        return issueTime;
    }

    public void setIssueTime(Date issueTime) {
        this.issueTime = issueTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}

==> mktcenter-service-threetree-1.0-20251014.094534-32-sources.jar: com/bizvane/mktcenterservice/models/po/MktActivityCertificationCertPO.java <==
package com.bizvane.mktcenterservice.models.po;

import java.util.Date;

public class MktActivityCertificationCertPO {
    private Long mktActivityCertificationCertId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long mktActivityCertificationId;

    private Long certificationTypeId;

    private String membersCode;

    private String memberPhone;

    private String cardNo;

    private String certImg;

    private String certLevel;

    private String certNo;

    private Integer certState;

    private Date issueTime;

    private Date expireTime;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Integer valid;

    public Long getMktActivityCertificationCertId() {
        return mktActivityCertificationCertId;
    }

    public void setMktActivityCertificationCertId(Long mktActivityCertificationCertId) {
        this.mktActivityCertificationCertId = mktActivityCertificationCertId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getMktActivityCertificationId() {
        return mktActivityCertificationId;
    }

    public void setMktActivityCertificationId(Long mktActivityCertificationId) {
        this.mktActivityCertificationId = mktActivityCertificationId;
    }

    public Long getCertificationTypeId() {
        return certificationTypeId;
    }

    public void setCertificationTypeId(Long certificationTypeId) {
        this.certificationTypeId = certificationTypeId;
    }

    public String getMembersCode() {
        return membersCode;
    }

    public void setMembersCode(String membersCode) {
        this.membersCode = membersCode == null ? null : membersCode.trim();
    }

    public String getMemberPhone() {
        return memberPhone;
    }

    public void setMemberPhone(String memberPhone) {
        this.memberPhone = memberPhone == null ? null : memberPhone.trim();
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo == null ? null : cardNo.trim();
    }

    public String getCertImg() {
        return certImg;
    }

    public void setCertImg(String certImg) {
        this.certImg = certImg == null ? null : certImg.trim();
    }

    public String getCertLevel() {
        return certLevel;
    }

    public void setCertLevel(String certLevel) {
        this.certLevel = certLevel == null ? null : certLevel.trim();
    }

    public String getCertNo() {
        return certNo;
    }

    public void setCertNo(String certNo) {
        this.certNo = certNo == null ? null : certNo.trim();
    }

    public Integer getCertState() {
        return certState;
    }

    public void setCertState(Integer certState) {
        this.certState = certState;
    }

    public Date getIssueTime() {
        return issueTime;
    }

    public void setIssueTime(Date issueTime) {
        this.issueTime = issueTime;
    }

    public Date getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(Date expireTime) {
        this.expireTime = expireTime;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Integer getValid() {
        return valid;
    }

    public void setValid(Integer valid) {
        this.valid = valid;
    }
}
